from setuptools import setup

setup(name='gaus_simdist',
      version='0.1',
      description='Gaussian distributions',
      packages=['gaus_simdist'],
      author = ["udemy course"],
      zip_safe=False)
